@@ -2,19 +2,18 @@ import re
 from typing import Callable, Literal
 from typing import Union, Optional
 
-from lxml import etree
-from pydantic import BaseModel
-from pydantic import Field
-
 from duowen_agent.agents.component.base import BaseComponent
+from duowen_agent.error import ObserverException
 from duowen_agent.llm import OpenAIChat, MessagesSet
+from duowen_agent.prompt.prompt_build import prompt_now_day
 from duowen_agent.tools.entity import ToolSearchResult
+from duowen_agent.utils.core_utils import generate_unique_id, remove_think
 from duowen_agent.utils.core_utils import stream_to_string
 from duowen_agent.utils.string_template import StringTemplate
 from duowen_agent.utils.xml_tool_parser import parse_xml_tool_calls
-from ..error import ObserverException
-from ..prompt.prompt_build import prompt_now_day
-from ..utils.core_utils import generate_unique_id, remove_think
+from lxml import etree
+from pydantic import BaseModel
+from pydantic import Field
 
 
 def extract_between(text: str, start_tag: str, end_tag: str) -> list[str]:
@@ -525,7 +524,7 @@ class DeepSearch:
                 if not _doc.result:
                     if self.self_qa_llm_instance:
                         res = stream_to_string(
-                            self.self_qa_llm_instance.chat(
+                            self.self_qa_llm_instance.chat_for_stream(
                                 MessagesSet()
                                 .add_system(
                                     "请用中立、客观的方式回答以下问题，语言需简明扼要（不超过3-5句话），避免主观推测或冗长解释。如果问题涉及争议性话题，请提供事实性信息并平衡相关观点。",
