@@ -2,7 +2,10 @@
 # SPDX-License-Identifier: MIT
 from typing import Optional, Callable
 
+from langgraph.prebuilt.chat_agent_executor import AgentState
+
 from duowen_agent.agents.react import ReactAgent
+from duowen_agent.deep_research import Configuration
 from duowen_agent.llm.chat_model import BaseAIChat
 from ..prompts import apply_prompt_template
 
@@ -15,6 +18,8 @@ def create_agent(
     agent_prompt: str = None,
     max_iterations: Optional[int] = 15,
     is_interrupt: Callable[[], bool] = None,
+    state: AgentState | dict = None,
+    configurable: Configuration = None,
 ) -> ReactAgent:
     """Factory function to create agents with consistent configuration."""
 
@@ -22,7 +27,11 @@ def create_agent(
         llm=llm,
         tools=tools,
         max_iterations=max_iterations,
-        prefix_prompt=agent_prompt
-        or apply_prompt_template(prompt_template)[0]["content"],
+        prefix_prompt=apply_prompt_template(
+            prompt_name=prompt_template,
+            prompt_template=agent_prompt,
+            state=state,
+            configurable=configurable,
+        )[0]["content"],
         is_interrupt=is_interrupt,
     )
