@@ -1,7 +1,8 @@
-from typing import Literal, Optional
+from typing import Literal, Optional, List
+
+from pydantic import BaseModel
 
 from duowen_agent.agents.react import ReactObservation, ReactAction, ReactResult
-from pydantic import BaseModel
 
 
 class MsgInfo(BaseModel):
@@ -13,8 +14,15 @@ class HumanFeedbackInfo(BaseModel):
     content: str
 
 
+class PlanStep(BaseModel):
+    title: str
+    description: Optional[str]
+    status: Literal["success", "running", "failed", "waiting"]
+
+
 class PlanInfo(BaseModel):
-    content: str
+    title: str
+    steps: List[PlanStep]
 
 
 class ReactStartInfo(BaseModel):
