@@ -17,7 +17,7 @@ from duowen_agent.llm import (
 )
 from duowen_agent.rag.models import Document
 from duowen_agent.rag.splitter.separator import SeparatorChunker
-from duowen_agent.utils.core_utils import retrying, json_observation
+from duowen_agent.utils.core_utils import retrying, json_observation, stream_to_string
 from .base import BaseChunk
 
 
@@ -253,10 +253,12 @@ Refer to the following JSON format for output:
         _sys_msg = self.template_str.format(start_line=start_line, end_line=end_line)
         _usr_msg = document_with_line_numbers
 
-        _data = self.llm_instance.chat(
-            messages=MessagesSet([SystemMessage(_sys_msg), UserMessage(_usr_msg)]),
-            temperature=0,
-            max_tokens=4000,
+        _data = stream_to_string(
+            self.llm_instance.chat_for_stream(
+                messages=MessagesSet([SystemMessage(_sys_msg), UserMessage(_usr_msg)]),
+                temperature=0,
+                max_tokens=4000,
+            )
         )
 
         return json_observation(_data, StructuredDocumentEnt)
@@ -485,8 +487,8 @@ Section name: {section_title}
             truncation_message=truncation_message,
         )
 
-        document_title = self.llm_instance.chat(
-            prompt, temperature=0.2, max_tokens=1000
+        document_title = stream_to_string(
+            self.llm_instance.chat_for_stream(prompt, temperature=0.2, max_tokens=1000)
         )
         return document_title
 
@@ -511,8 +513,8 @@ Section name: {section_title}
             truncation_message=truncation_message,
         )
 
-        document_summary = self.llm_instance.chat(
-            prompt, temperature=0.2, max_tokens=1000
+        document_summary = stream_to_string(
+            self.llm_instance.chat_for_stream(prompt, temperature=0.2, max_tokens=1000)
         )
         return document_summary
 
@@ -529,8 +531,8 @@ Section name: {section_title}
             document_title=document_title,
             section_title=section_title,
         )
-        section_summary = self.llm_instance.chat(
-            prompt, temperature=0.2, max_tokens=1000
+        section_summary = stream_to_string(
+            self.llm_instance.chat_for_stream(prompt, temperature=0.2, max_tokens=1000)
         )
         return section_summary
 
